@@ -27,9 +27,9 @@ sub execute {
     my $xs = XML::Simple->new(ForceArray => 0,);
 
     my $stash_key = (
-            $controller->config->{'serialize'} ?
-                $controller->config->{'serialize'}->{'stash_key'} :
-                $controller->config->{'stash_key'} 
+            $controller->{'serialize'} ?
+                $controller->{'serialize'}->{'stash_key'} :
+                $controller->{'stash_key'} 
         ) || 'rest';
     my $output;
     eval {
